==> 0.0.1.tar.gz: ios/Classes/SwiftPhylloConnectPlugin.swift <==
import Flutter
import UIKit
import PhylloConnect

public class SwiftPhylloConnectPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "phyllo_connect", binaryMessenger: registrar.messenger())
        let instance = SwiftPhylloConnectPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        if call.method == "getPhylloEnvironmentUrl" {
            if let args = call.arguments as? Dictionary<String, Any>{
                
                let envType = args["type"] as? String
                let env = getPhylloEnvironment(env: envType)
                result(env.rawValue)
                
            } else {
                result("error")
            }
            
        } else if call.method == "launchPhylloConnectSdk" {
            
            print(call.arguments as Any)
        
            if let args  = call.arguments as? Dictionary<String, Any>{
                launchPhylloConnectSdk(arguments: args)
            } else {
                result("error")
            }
            
            
        } else {
            
            result(FlutterMethodNotImplemented)
            
        }
    }
    
    
    public func getPhylloEnvironment(env :String?) -> PhylloEnvironment {
        switch (env) {
        case ("development"):
            return PhylloEnvironment.dev
        case ("sandbox"):
            return PhylloEnvironment.sandbox
        case ("production"):
            return PhylloEnvironment.prod
        default:
            return PhylloEnvironment.dev
        }
    }
    
    func launchPhylloConnectSdk(arguments : Dictionary<String, Any>){
    
        var phylloConfig = PhylloConfig()
        phylloConfig.developerName =  (arguments["appName"] as? String)!
        phylloConfig.deepLinkURL = "https://etsy.ai"
        phylloConfig.sdkToken = "Bearer " + (arguments["sdkToken"] as? String)!
        phylloConfig.userId = (arguments["userId"] as? String)!
        phylloConfig.env = getPhylloEnvironment(env: arguments["environment"] as? String)
        phylloConfig.phylloVC = getPhylloViewController()!
        
        let phyllo = PhylloConnect(configuration: phylloConfig)
        phyllo.launchSDK(workPlatformId: (arguments["platformId"] as? String)!)
        
    }
    
    func getPhylloViewController() -> UIViewController? {
        var viewController: UIViewController? = UIApplication.shared.keyWindow?.rootViewController as! FlutterViewController
        while viewController?.presentedViewController != nil {
            viewController = viewController?.presentedViewController
        }
        return viewController
    }
}

==> 0.1.9.tar.gz: ios/Classes/SwiftPhylloConnectPlugin.swift <==
import Flutter
import UIKit
import PhylloConnect

public class SwiftPhylloConnectPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "phyllo_connect", binaryMessenger: registrar.messenger())
        let instance = SwiftPhylloConnectPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        if call.method == "getPhylloEnvironmentUrl" {
            if let args = call.arguments as? Dictionary<String, Any>{
                
                let envType = args["type"] as? String
                let env = getPhylloEnvironment(env: envType)
                result(env.rawValue)
                
            } else {
                result("error")
            }
            
        } else if call.method == "initPhylloConnect" {
            
            print(call.arguments as Any)
            
            if let args  = call.arguments as? Dictionary<String, Any>{
                initPhylloConnect(config: args)
            } else {
                result("error")
            }
            
            
        } else {
            
            result(FlutterMethodNotImplemented)
            
        }
    }
    
    
    public func getPhylloEnvironment(env :String?) -> PhylloEnvironment {
        switch (env) {
        case ("development"):
            return PhylloEnvironment.dev
        case ("sandbox"):
            return PhylloEnvironment.sandbox
        case ("production"):
            return PhylloEnvironment.prod
        default:
            return PhylloEnvironment.dev
        }
    }
    
    func initPhylloConnect(config : Dictionary<String, Any>){
        
        var phylloConfig = PhylloConfig()
        phylloConfig.clientDisplayName =  (config["clientDisplayName"] as? String)!
        phylloConfig.token = "Bearer " + (config["token"] as? String)!
        phylloConfig.userId = (config["userId"] as? String)!
        phylloConfig.environment = getPhylloEnvironment(env: config["environment"] as? String)
        phylloConfig.workPlatformId = (config["workPlatformId"] as? String)!
        
        let phyllo = PhylloConnect(config: phylloConfig)
        phyllo.open()
    }
    
    
}
